# Notifo::MediaApi

All URIs are relative to *https://notifo.easierlife.com*

Method | HTTP request | Description
------------- | ------------- | -------------
[**media_delete**](MediaApi.md#media_delete) | **DELETE** /api/apps/{appId}/media/{fileName} | Delete a media.
[**media_download**](MediaApi.md#media_download) | **GET** /api/apps/{appId}/media/{fileName} | Download a media object.
[**media_download2**](MediaApi.md#media_download2) | **GET** /api/assets/{appId}/{fileName} | Download a media object.
[**media_get_medias**](MediaApi.md#media_get_medias) | **GET** /api/apps/{appId}/media | Query media items.
[**media_upload**](MediaApi.md#media_upload) | **POST** /api/apps/{appId}/media | Upload a media object.

# **media_delete**
> media_delete(app_id, file_name)

Delete a media.

### Example
```ruby
# load the gem
require 'notifo'

api_instance = Notifo::MediaApi.new
app_id = 'app_id_example' # String | The app id where the media belongs to.
file_name = 'file_name_example' # String | The file name of the media.


begin
  #Delete a media.
  api_instance.media_delete(app_id, file_name)
rescue Notifo::ApiError => e
  puts "Exception when calling MediaApi->media_delete: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **app_id** | **String**| The app id where the media belongs to. | 
 **file_name** | **String**| The file name of the media. | 

### Return type

nil (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **media_download**
> String media_download(app_id, file_name, opts)

Download a media object.

### Example
```ruby
# load the gem
require 'notifo'

api_instance = Notifo::MediaApi.new
app_id = 'app_id_example' # String | The app id where the media belongs to.
file_name = 'file_name_example' # String | The name of the media to download.
opts = { 
  cache: 789, # Integer | The cache duration.
  download: 56, # Integer | Set it to 1 to create a download response.
  width: 56, # Integer | The target width when an image.
  height: 56, # Integer | The target height when an image.
  quality: 56, # Integer | The target quality when an image.
  preset: 'preset_example', # String | A preset dimension.
  mode: Notifo::ResizeMode.new, # ResizeMode | The resize mode.
  focus_x: 3.4, # Float | The x position of the focues point.
  focus_y: 3.4, # Float | The y position of the focues point.
  force: true # BOOLEAN | True to resize it and clear the cache.
}

begin
  #Download a media object.
  result = api_instance.media_download(app_id, file_name, opts)
  p result
rescue Notifo::ApiError => e
  puts "Exception when calling MediaApi->media_download: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **app_id** | **String**| The app id where the media belongs to. | 
 **file_name** | **String**| The name of the media to download. | 
 **cache** | **Integer**| The cache duration. | [optional] 
 **download** | **Integer**| Set it to 1 to create a download response. | [optional] 
 **width** | **Integer**| The target width when an image. | [optional] 
 **height** | **Integer**| The target height when an image. | [optional] 
 **quality** | **Integer**| The target quality when an image. | [optional] 
 **preset** | **String**| A preset dimension. | [optional] 
 **mode** | [**ResizeMode**](.md)| The resize mode. | [optional] 
 **focus_x** | **Float**| The x position of the focues point. | [optional] 
 **focus_y** | **Float**| The y position of the focues point. | [optional] 
 **force** | **BOOLEAN**| True to resize it and clear the cache. | [optional] 

### Return type

**String**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/octet-stream, application/json



# **media_download2**
> String media_download2(app_id, file_name, opts)

Download a media object.

### Example
```ruby
# load the gem
require 'notifo'

api_instance = Notifo::MediaApi.new
app_id = 'app_id_example' # String | The app id where the media belongs to.
file_name = 'file_name_example' # String | The name of the media to download.
opts = { 
  cache: 789, # Integer | The cache duration.
  download: 56, # Integer | Set it to 1 to create a download response.
  width: 56, # Integer | The target width when an image.
  height: 56, # Integer | The target height when an image.
  quality: 56, # Integer | The target quality when an image.
  preset: 'preset_example', # String | A preset dimension.
  mode: Notifo::ResizeMode.new, # ResizeMode | The resize mode.
  focus_x: 3.4, # Float | The x position of the focues point.
  focus_y: 3.4, # Float | The y position of the focues point.
  force: true # BOOLEAN | True to resize it and clear the cache.
}

begin
  #Download a media object.
  result = api_instance.media_download2(app_id, file_name, opts)
  p result
rescue Notifo::ApiError => e
  puts "Exception when calling MediaApi->media_download2: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **app_id** | **String**| The app id where the media belongs to. | 
 **file_name** | **String**| The name of the media to download. | 
 **cache** | **Integer**| The cache duration. | [optional] 
 **download** | **Integer**| Set it to 1 to create a download response. | [optional] 
 **width** | **Integer**| The target width when an image. | [optional] 
 **height** | **Integer**| The target height when an image. | [optional] 
 **quality** | **Integer**| The target quality when an image. | [optional] 
 **preset** | **String**| A preset dimension. | [optional] 
 **mode** | [**ResizeMode**](.md)| The resize mode. | [optional] 
 **focus_x** | **Float**| The x position of the focues point. | [optional] 
 **focus_y** | **Float**| The y position of the focues point. | [optional] 
 **force** | **BOOLEAN**| True to resize it and clear the cache. | [optional] 

### Return type

**String**

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/octet-stream, application/json



# **media_get_medias**
> ListResponseDtoOfMediaDto media_get_medias(app_id, opts)

Query media items.

### Example
```ruby
# load the gem
require 'notifo'

api_instance = Notifo::MediaApi.new
app_id = 'app_id_example' # String | The app where the media belongs to.
opts = { 
  query: 'query_example', # String | The optional query to search for items.
  take: 56, # Integer | The number of items to return.
  skip: 56 # Integer | The number of items to skip.
}

begin
  #Query media items.
  result = api_instance.media_get_medias(app_id, opts)
  p result
rescue Notifo::ApiError => e
  puts "Exception when calling MediaApi->media_get_medias: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **app_id** | **String**| The app where the media belongs to. | 
 **query** | **String**| The optional query to search for items. | [optional] 
 **take** | **Integer**| The number of items to return. | [optional] 
 **skip** | **Integer**| The number of items to skip. | [optional] 

### Return type

[**ListResponseDtoOfMediaDto**](ListResponseDtoOfMediaDto.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **media_upload**
> media_upload(app_id, opts)

Upload a media object.

### Example
```ruby
# load the gem
require 'notifo'

api_instance = Notifo::MediaApi.new
app_id = 'app_id_example' # String | The app id where the media belongs to.
opts = { 
  file: 'file_example' # String | 
}

begin
  #Upload a media object.
  api_instance.media_upload(app_id, opts)
rescue Notifo::ApiError => e
  puts "Exception when calling MediaApi->media_upload: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **app_id** | **String**| The app id where the media belongs to. | 
 **file** | **String**|  | [optional] 

### Return type

nil (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: multipart/form-data
 - **Accept**: application/json



