# Notifo::UsersApi

All URIs are relative to *https://notifo.easierlife.com*

Method | HTTP request | Description
------------- | ------------- | -------------
[**users_delete_allowed_topic**](UsersApi.md#users_delete_allowed_topic) | **DELETE** /api/apps/{appId}/users/{id}/allowed-topics/{prefix} | Remove an allowed topic.
[**users_delete_subscription**](UsersApi.md#users_delete_subscription) | **DELETE** /api/apps/{appId}/users/{id}/subscriptions/{prefix} | Remove a user subscriptions.
[**users_delete_user**](UsersApi.md#users_delete_user) | **DELETE** /api/apps/{appId}/users/{id} | Delete a user.
[**users_get_subscriptions**](UsersApi.md#users_get_subscriptions) | **GET** /api/apps/{appId}/users/{id}/subscriptions | Query user subscriptions.
[**users_get_user**](UsersApi.md#users_get_user) | **GET** /api/apps/{appId}/users/{id} | Get a user.
[**users_get_users**](UsersApi.md#users_get_users) | **GET** /api/apps/{appId}/users | Query users.
[**users_post_allowed_topic**](UsersApi.md#users_post_allowed_topic) | **POST** /api/apps/{appId}/users/{id}/allowed-topics | Add an allowed topic.
[**users_post_subscription**](UsersApi.md#users_post_subscription) | **POST** /api/apps/{appId}/users/{id}/subscriptions | Upsert a user subscriptions.
[**users_post_users**](UsersApi.md#users_post_users) | **POST** /api/apps/{appId}/users | Upsert users.

# **users_delete_allowed_topic**
> users_delete_allowed_topic(app_id, id, prefix)

Remove an allowed topic.

### Example
```ruby
# load the gem
require 'notifo'

api_instance = Notifo::UsersApi.new
app_id = 'app_id_example' # String | The app where the users belong to.
id = 'id_example' # String | The user id.
prefix = 'prefix_example' # String | The topic prefix.


begin
  #Remove an allowed topic.
  api_instance.users_delete_allowed_topic(app_id, id, prefix)
rescue Notifo::ApiError => e
  puts "Exception when calling UsersApi->users_delete_allowed_topic: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **app_id** | **String**| The app where the users belong to. | 
 **id** | **String**| The user id. | 
 **prefix** | **String**| The topic prefix. | 

### Return type

nil (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **users_delete_subscription**
> users_delete_subscription(app_id, id, prefix)

Remove a user subscriptions.

### Example
```ruby
# load the gem
require 'notifo'

api_instance = Notifo::UsersApi.new
app_id = 'app_id_example' # String | The app where the user belongs to.
id = 'id_example' # String | The user id.
prefix = 'prefix_example' # String | The topic prefix.


begin
  #Remove a user subscriptions.
  api_instance.users_delete_subscription(app_id, id, prefix)
rescue Notifo::ApiError => e
  puts "Exception when calling UsersApi->users_delete_subscription: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **app_id** | **String**| The app where the user belongs to. | 
 **id** | **String**| The user id. | 
 **prefix** | **String**| The topic prefix. | 

### Return type

nil (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **users_delete_user**
> ListResponseDtoOfUserDto users_delete_user(app_id, id)

Delete a user.

### Example
```ruby
# load the gem
require 'notifo'

api_instance = Notifo::UsersApi.new
app_id = 'app_id_example' # String | The app where the users belongs to.
id = 'id_example' # String | The user id to delete.


begin
  #Delete a user.
  result = api_instance.users_delete_user(app_id, id)
  p result
rescue Notifo::ApiError => e
  puts "Exception when calling UsersApi->users_delete_user: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **app_id** | **String**| The app where the users belongs to. | 
 **id** | **String**| The user id to delete. | 

### Return type

[**ListResponseDtoOfUserDto**](ListResponseDtoOfUserDto.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **users_get_subscriptions**
> ListResponseDtoOfSubscriptionDto users_get_subscriptions(app_id, id, opts)

Query user subscriptions.

### Example
```ruby
# load the gem
require 'notifo'

api_instance = Notifo::UsersApi.new
app_id = 'app_id_example' # String | The app where the user belongs to.
id = 'id_example' # String | The user id.
opts = { 
  query: 'query_example', # String | The optional query to search for items.
  take: 56, # Integer | The number of items to return.
  skip: 56 # Integer | The number of items to skip.
}

begin
  #Query user subscriptions.
  result = api_instance.users_get_subscriptions(app_id, id, opts)
  p result
rescue Notifo::ApiError => e
  puts "Exception when calling UsersApi->users_get_subscriptions: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **app_id** | **String**| The app where the user belongs to. | 
 **id** | **String**| The user id. | 
 **query** | **String**| The optional query to search for items. | [optional] 
 **take** | **Integer**| The number of items to return. | [optional] 
 **skip** | **Integer**| The number of items to skip. | [optional] 

### Return type

[**ListResponseDtoOfSubscriptionDto**](ListResponseDtoOfSubscriptionDto.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **users_get_user**
> ListResponseDtoOfUserDto users_get_user(app_id, id)

Get a user.

### Example
```ruby
# load the gem
require 'notifo'

api_instance = Notifo::UsersApi.new
app_id = 'app_id_example' # String | The app where the user belongs to.
id = 'id_example' # String | The user id.


begin
  #Get a user.
  result = api_instance.users_get_user(app_id, id)
  p result
rescue Notifo::ApiError => e
  puts "Exception when calling UsersApi->users_get_user: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **app_id** | **String**| The app where the user belongs to. | 
 **id** | **String**| The user id. | 

### Return type

[**ListResponseDtoOfUserDto**](ListResponseDtoOfUserDto.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **users_get_users**
> ListResponseDtoOfUserDto users_get_users(app_id, opts)

Query users.

### Example
```ruby
# load the gem
require 'notifo'

api_instance = Notifo::UsersApi.new
app_id = 'app_id_example' # String | The app where the users belongs to.
opts = { 
  query: 'query_example', # String | The optional query to search for items.
  take: 56, # Integer | The number of items to return.
  skip: 56 # Integer | The number of items to skip.
}

begin
  #Query users.
  result = api_instance.users_get_users(app_id, opts)
  p result
rescue Notifo::ApiError => e
  puts "Exception when calling UsersApi->users_get_users: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **app_id** | **String**| The app where the users belongs to. | 
 **query** | **String**| The optional query to search for items. | [optional] 
 **take** | **Integer**| The number of items to return. | [optional] 
 **skip** | **Integer**| The number of items to skip. | [optional] 

### Return type

[**ListResponseDtoOfUserDto**](ListResponseDtoOfUserDto.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: Not defined
 - **Accept**: application/json



# **users_post_allowed_topic**
> users_post_allowed_topic(bodyapp_idid)

Add an allowed topic.

### Example
```ruby
# load the gem
require 'notifo'

api_instance = Notifo::UsersApi.new
body = Notifo::AddAllowedTopicDto.new # AddAllowedTopicDto | The upsert request.
app_id = 'app_id_example' # String | The app where the users belong to.
id = 'id_example' # String | The user id.


begin
  #Add an allowed topic.
  api_instance.users_post_allowed_topic(bodyapp_idid)
rescue Notifo::ApiError => e
  puts "Exception when calling UsersApi->users_post_allowed_topic: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**AddAllowedTopicDto**](AddAllowedTopicDto.md)| The upsert request. | 
 **app_id** | **String**| The app where the users belong to. | 
 **id** | **String**| The user id. | 

### Return type

nil (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **users_post_subscription**
> users_post_subscription(bodyapp_idid)

Upsert a user subscriptions.

### Example
```ruby
# load the gem
require 'notifo'

api_instance = Notifo::UsersApi.new
body = Notifo::SubscriptionDto.new # SubscriptionDto | The subscription object.
app_id = 'app_id_example' # String | The app where the user belongs to.
id = 'id_example' # String | The user id.


begin
  #Upsert a user subscriptions.
  api_instance.users_post_subscription(bodyapp_idid)
rescue Notifo::ApiError => e
  puts "Exception when calling UsersApi->users_post_subscription: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**SubscriptionDto**](SubscriptionDto.md)| The subscription object. | 
 **app_id** | **String**| The app where the user belongs to. | 
 **id** | **String**| The user id. | 

### Return type

nil (empty response body)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



# **users_post_users**
> Array&lt;UserDto&gt; users_post_users(bodyapp_id)

Upsert users.

### Example
```ruby
# load the gem
require 'notifo'

api_instance = Notifo::UsersApi.new
body = Notifo::UpsertUsersDto.new # UpsertUsersDto | The upsert request.
app_id = 'app_id_example' # String | The app where the users belong to.


begin
  #Upsert users.
  result = api_instance.users_post_users(bodyapp_id)
  p result
rescue Notifo::ApiError => e
  puts "Exception when calling UsersApi->users_post_users: #{e}"
end
```

### Parameters

Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **body** | [**UpsertUsersDto**](UpsertUsersDto.md)| The upsert request. | 
 **app_id** | **String**| The app where the users belong to. | 

### Return type

[**Array&lt;UserDto&gt;**](UserDto.md)

### Authorization

No authorization required

### HTTP request headers

 - **Content-Type**: application/json
 - **Accept**: application/json



